| Home | Libraries | People | FAQ | More

### Hypergeometric References

1. Beals, Richard, and Roderick Wong. Special functions: a graduate text. Vol. 126. Cambridge University Press, 2010.
2. Pearson, John W., Sheehan Olver, and Mason A. Porter. Numerical methods for the computation of the confluent and Gauss hypergeometric functions. Numerical Algorithms 74.3 (2017): 821-866.
3. Luke, Yudell L. Algorithms for Rational Approximations for a Confluent Hypergeometric Function II. MISSOURI UNIV KANSAS CITY DEPT OF MATHEMATICS, 1976.
4. Derezinski, Jan. Hypergeometric type functions and their symmetries. Annales Henri Poincaré. Vol. 15. No. 8. Springer Basel, 2014.
5. Keith E. Muller Computing the confluent hypergeometric function, M(a, b, x). Numer. Math. 90: 179-196 (2001).
6. Carlo Morosi, Livio Pizzocchero. On the expansion of the Kummer function in terms of incomplete Gamma functions. Arch. Inequal. Appl. 2 (2004), 49-72.
7. Jose Luis Lopez, Nico M. Temme. Asymptotics and numerics of polynomials used in Tricomi and Buchholz expansions of Kummer functions. Numerische Mathematik, August 2010.
8. Javier Sesma. The Temme's sum rule for confluent hypergeometric functions revisited. Journal of Computational and Applied Mathematics 163 (2004) 429-431.
9. Javier Segura, Nico M. Temme. Numerically satisfactory solutions of Kummer recurrence relations. Numer. Math. (2008) 111:109-119.
10. Alfredo Deano, Javier Segura. Transitory Minimal Solutions Of Hypergeometric Recursions And Pseudoconvergence of Associated Continued Fractions. Mathematics of Computation, Volume 76, Number 258, April 2007.
11. W. Gautschi. Computational aspects of three-term recurrence relations. SIAM Review 9, no.1 (1967) 24-82.
12. W. Gautschi. Anomalous convergence of a continued fraction for ratios of Kummer functions. Math. Comput., 31, no.140 (1977) 994-999.
13. British Association for the Advancement of Science: Bessel functions, Part II, Mathematical Tables vol. X. Cambridge (1952).